@@ -1,5 +1,5 @@
-from .constants import PANDAS_TYPES, PYSPARK_TYPES, KOALAS_TYPES, PANDAS_ON_SPARK_TYPES, PANDAS, KOALAS, SPARK, PYSPARK, PANDAS_ON_SPARK, IN_PANDAS_ON_SPARK
-from .functions import get_spark, get_dbutils, data_convert, to_list, df_type
+from hivecore.constant import PANDAS_TYPES, PYSPARK_TYPES, KOALAS_TYPES, PANDAS_ON_SPARK_TYPES, PANDAS, KOALAS, SPARK, PYSPARK, PANDAS_ON_SPARK, IN_PANDAS_ON_SPARK
+from hiveadb.function import get_spark, get_dbutils, data_convert, to_list, df_type
 
 from pyspark.ml.stat import Correlation
 from pyspark.ml.feature import VectorAssembler
